@@ -2,6 +2,7 @@
 Shipyard Python SDK - Session ship implementation
 """
 
+import os
 from typing import Dict, Any, TYPE_CHECKING
 from .types import ShipInfo
 from .filesystem import FileSystemComponent
@@ -34,3 +35,22 @@ class SessionShip(ShipInfo):
     async def get_logs(self) -> str:
         """Get ship container logs"""
         return await self._client.get_ship_logs(self.id)
+
+    async def upload_file(
+        self, file_path: str, remote_file_path: str | None = None
+    ) -> Dict[str, Any]:
+        """Upload file to this ship session
+
+        Args:
+            file_path: Path to the local file to upload
+            remote_file_path: Path where the file should be saved in the ship workspace.
+
+        Returns:
+            Dictionary with upload result information
+        """
+        if not remote_file_path:
+            remote_file_path = os.path.basename(file_path)
+
+        return await self._client.upload_file(
+            self.id, file_path, self._session_id, remote_file_path
+        )
